@@ -1,7 +1,7 @@
-'use strict';
+"use strict";
 
-var GenericWorker = require('./GenericWorker');
-var utils = require('../utils');
+var GenericWorker = require("./GenericWorker");
+var utils = require("../utils");
 
 /**
  * A worker which convert chunks to a specified type.
