@@ -1,5 +1,4 @@
-/* global QUnit,JSZip,JSZipTestUtils */
-'use strict';
+"use strict";
 
 QUnit.module("permissions", function () {
 
@@ -23,16 +22,16 @@ QUnit.module("permissions", function () {
 
         var done = assert.async();
         JSZip.loadAsync(file, {createFolders:false})
-        .then(function(zip) {
-            doAsserts(zip, "dir_777/", true,  "40777");
-            doAsserts(zip, "dir_755/", true,  "40755");
-            doAsserts(zip, "dir_500/", true,  "40500");
-            doAsserts(zip, "file_666", false, "100666");
-            doAsserts(zip, "file_640", false, "100640");
-            doAsserts(zip, "file_400", false, "100400");
-            doAsserts(zip, "file_755", false, "100755");
-            done();
-        })['catch'](JSZipTestUtils.assertNoError);
+            .then(function(zip) {
+                doAsserts(zip, "dir_777/", true,  "40777");
+                doAsserts(zip, "dir_755/", true,  "40755");
+                doAsserts(zip, "dir_500/", true,  "40500");
+                doAsserts(zip, "file_666", false, "100666");
+                doAsserts(zip, "file_640", false, "100640");
+                doAsserts(zip, "file_400", false, "100400");
+                doAsserts(zip, "file_755", false, "100755");
+                done();
+            })["catch"](JSZipTestUtils.assertNoError);
     }
 
     function assertDosPermissions(assert, file){
@@ -45,42 +44,42 @@ QUnit.module("permissions", function () {
 
         var done = assert.async();
         JSZip.loadAsync(file, {createFolders:false})
-        .then(function(zip) {
-            if (zip.files["dir/"]) {
-                doAsserts(zip, "dir/",           true,  "010000");
-            }
-            if (zip.files["dir_hidden/"]) {
-                doAsserts(zip, "dir_hidden/",    true,  "010010");
-            }
-            doAsserts(zip, "file",           false, "100000");
-            doAsserts(zip, "file_ro",        false, "100001");
-            doAsserts(zip, "file_hidden",    false, "100010");
-            doAsserts(zip, "file_ro_hidden", false, "100011");
-            done();
-        })['catch'](JSZipTestUtils.assertNoError);
+            .then(function(zip) {
+                if (zip.files["dir/"]) {
+                    doAsserts(zip, "dir/",           true,  "010000");
+                }
+                if (zip.files["dir_hidden/"]) {
+                    doAsserts(zip, "dir_hidden/",    true,  "010010");
+                }
+                doAsserts(zip, "file",           false, "100000");
+                doAsserts(zip, "file_ro",        false, "100001");
+                doAsserts(zip, "file_hidden",    false, "100010");
+                doAsserts(zip, "file_ro_hidden", false, "100011");
+                done();
+            })["catch"](JSZipTestUtils.assertNoError);
     }
 
     function reloadAndAssertUnixPermissions(assert, file){
         var done = assert.async();
         JSZip.loadAsync(file, {createFolders:false})
-        .then(function (zip) {
-            return zip.generateAsync({type:"string", platform:"UNIX"});
-        })
-        .then(function (content) {
-            assertUnixPermissions(assert, content);
-            done();
-        })['catch'](JSZipTestUtils.assertNoError);
+            .then(function (zip) {
+                return zip.generateAsync({type:"string", platform:"UNIX"});
+            })
+            .then(function (content) {
+                assertUnixPermissions(assert, content);
+                done();
+            })["catch"](JSZipTestUtils.assertNoError);
     }
     function reloadAndAssertDosPermissions(assert, file){
         var done = assert.async();
         JSZip.loadAsync(file, {createFolders:false})
-        .then(function (zip) {
-            return zip.generateAsync({type:"string", platform:"DOS"});
-        })
-        .then(function (content) {
-            assertDosPermissions(assert, content);
-            done();
-        })['catch'](JSZipTestUtils.assertNoError);
+            .then(function (zip) {
+                return zip.generateAsync({type:"string", platform:"DOS"});
+            })
+            .then(function (content) {
+                assertDosPermissions(assert, content);
+                done();
+            })["catch"](JSZipTestUtils.assertNoError);
     }
     JSZipTestUtils.testZipFile("permissions on linux : file created by zip", "ref/permissions/linux_zip.zip", assertUnixPermissions);
     JSZipTestUtils.testZipFile("permissions on linux : file created by zip, reloaded", "ref/permissions/linux_zip.zip", reloadAndAssertUnixPermissions);
