@@ -1,5 +1,4 @@
-/* global JSZip,JSZipUtils,JSZipTestUtils */
-'use strict';
+"use strict";
 JSZipTestUtils.loadZipFile = function (name, callback) {
     JSZipUtils.getBinaryContent(name + "?_=" + ( new Date() ).getTime(), callback);
 };
